marktools.Articulation
======================

.. abjad-lineage:: abjad.tools.marktools.Articulation.Articulation.Articulation

.. autoclass:: abjad.tools.marktools.Articulation.Articulation.Articulation

.. only:: html

   Attribute summary
   -----------------

   .. autosummary::

      ~abjad.tools.marktools.Articulation.Articulation.Articulation.attach
      ~abjad.tools.marktools.Articulation.Articulation.Articulation.detach
      ~abjad.tools.marktools.Articulation.Articulation.Articulation.direction
      ~abjad.tools.marktools.Articulation.Articulation.Articulation.lilypond_format
      ~abjad.tools.marktools.Articulation.Articulation.Articulation.name
      ~abjad.tools.marktools.Articulation.Articulation.Articulation.start_component
      ~abjad.tools.marktools.Articulation.Articulation.Articulation.storage_format
      ~abjad.tools.marktools.Articulation.Articulation.Articulation.__call__
      ~abjad.tools.marktools.Articulation.Articulation.Articulation.__copy__
      ~abjad.tools.marktools.Articulation.Articulation.Articulation.__eq__
      ~abjad.tools.marktools.Articulation.Articulation.Articulation.__ne__
      ~abjad.tools.marktools.Articulation.Articulation.Articulation.__repr__
      ~abjad.tools.marktools.Articulation.Articulation.Articulation.__str__

Bases
-----

- :py:class:`marktools.DirectedMark <abjad.tools.marktools.DirectedMark.DirectedMark.DirectedMark>`

- :py:class:`marktools.Mark <abjad.tools.marktools.Mark.Mark.Mark>`

- :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

- :py:class:`__builtin__.object <object>`

Read-only properties
--------------------

.. autoattribute:: abjad.tools.marktools.Articulation.Articulation.Articulation.lilypond_format
   :noindex:

.. autoattribute:: abjad.tools.marktools.Articulation.Articulation.Articulation.start_component
   :noindex:

.. autoattribute:: abjad.tools.marktools.Articulation.Articulation.Articulation.storage_format
   :noindex:

Read/write properties
---------------------

.. autoattribute:: abjad.tools.marktools.Articulation.Articulation.Articulation.direction
   :noindex:

.. autoattribute:: abjad.tools.marktools.Articulation.Articulation.Articulation.name
   :noindex:

Methods
-------

.. automethod:: abjad.tools.marktools.Articulation.Articulation.Articulation.attach
   :noindex:

.. automethod:: abjad.tools.marktools.Articulation.Articulation.Articulation.detach
   :noindex:

Special methods
---------------

.. automethod:: abjad.tools.marktools.Articulation.Articulation.Articulation.__call__
   :noindex:

.. automethod:: abjad.tools.marktools.Articulation.Articulation.Articulation.__copy__
   :noindex:

.. automethod:: abjad.tools.marktools.Articulation.Articulation.Articulation.__eq__
   :noindex:

.. automethod:: abjad.tools.marktools.Articulation.Articulation.Articulation.__ne__
   :noindex:

.. automethod:: abjad.tools.marktools.Articulation.Articulation.Articulation.__repr__
   :noindex:

.. automethod:: abjad.tools.marktools.Articulation.Articulation.Articulation.__str__
   :noindex:
